%-----------------------------------------------------------------------
% File    : myslides.cls
% Contents: my personal slides document class
% Author  : Christian Borgelt
% History : 1996.12.18 file created as myslides.sty
%           1997.06.03 minor improvements
%           1997.07.24 bug concerning \unitlength fixed
%           2000.06.24 changed to a LaTeX2e package
%           2000.09.21 changed to a LaTeX2e document class
%           2005.11.10 page numbering/labeling added
%           2017.09.19 command \sx for bold sans-serif added
%           2017.10.03 environment slide* added (keep page/slide number)
%           2020.04.09 format options 4x3, 16x9 and a4paper added
%           2020.09.15 format options 16x10 added
%-----------------------------------------------------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{myslides}[2020/09/15 v2.4]
\usepackage{color}

\newcount\slide@format\slide@format=0
\DeclareOption{4x3}    {\global\slide@format=0}
\DeclareOption{16x9}   {\global\slide@format=1}
\DeclareOption{16x10}  {\global\slide@format=2}
\DeclareOption{a4paper}{\global\slide@format=3}
\ProcessOptions

%-----------------------------------------------------------------------
% Page Format
%-----------------------------------------------------------------------
\newcount\slide@wd
\newdimen\foot@wd

\ifcase\slide@format    % 4x3
  \paperheight   210mm
  \paperwidth    280mm
  \pdfpageheight \paperheight
  \pdfpagewidth  \paperwidth
  \textwidth     250mm
  \textheight    204mm
  \topmargin      -1in
  \footskip        6mm
  \slide@wd=280
\or                     % 16x9
  \paperheight   210mm
  \paperwidth    373.04mm
  \pdfpageheight \paperheight
  \pdfpagewidth  \paperwidth
  \textwidth     320mm
  \textheight    204mm
  \topmargin      -1in
  \footskip        6mm
  \slide@wd=373
\or                     % 16x10
  \paperheight   210mm
  \paperwidth    336mm
  \pdfpageheight \paperheight
  \pdfpagewidth  \paperwidth
  \textwidth     306mm
  \textheight    204mm
  \topmargin      -1in
  \footskip        6mm
  \slide@wd=336
\else                   % a4paper
  \paperheight   210mm
  \paperwidth    297.05mm
  \pdfpageheight \paperheight
  \pdfpagewidth  \paperwidth
  \textwidth     267mm
  \textheight    204mm
  \topmargin      -1in
  \footskip        6mm
  \slide@wd=297
\fi

\oddsidemargin\paperwidth
\advance\oddsidemargin-\textwidth
\divide\oddsidemargin2
\advance\oddsidemargin-1in

\headheight\z@
\headsep   \z@
\topskip   \z@
\parindent \z@
\parskip   \z@

\foot@wd\slide@wd mm
\advance\foot@wd-4mm

%-----------------------------------------------------------------------
% Font Definitions
%-----------------------------------------------------------------------

\DeclareFontFamily{OT1}{lcmr}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{lcmr}{m}{n}{%
  <3><4>cmr5%
  <5><6><7><8>gen*cmr%
  <10><10.95>cmr10%
  <12><14.4>cmr12%
  <17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmr17}{}
\DeclareFontShape{OT1}{lcmr}{m}{sl}{%
  <3><4><5><6><7><8>cmsl8%
  <10><10.95>cmsl10%
  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmsl12}{}
\DeclareFontShape{OT1}{lcmr}{m}{it}{%
  <3><4><5><6><7>cmti7%
  <8>cmti8%
  <9>cmti9%
  <10><10.95>cmti10%
  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmti12}{}
\DeclareFontShape{OT1}{lcmr}{m}{sc}{%
  <3><4><5><6><7><8><9><10><10.95><12>%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmcsc10}{}
\DeclareFontShape{OT1}{lcmr}{m}{ui}{%
  <3><4><5><6><7><8><9><10><10.95><12>%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmu10}{}
\DeclareFontShape{OT1}{lcmr}{b}{n}{%
  <3><4><5>cmbx5%
  <6><7><8><9>gen*cmbx%
  <10><10.95>cmbx10%
  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmbx12}{}
\DeclareFontShape{OT1}{lcmr}{b}{sl}{%
  <3><4><5><6><7><8><9>%
  <10><10.95><12><14.4><17.28>%
  <20.74><24.88><29.86><35.83><43.00><51.6>cmbxsl10}{}
\DeclareFontShape{OT1}{lcmr}{b}{it}{%
  <3><4><5><6><7><8><9>%
  <10><10.95><12><14.4><17.28>%
  <20.74><24.88><29.86><35.83><43.00><51.6>cmbxti10}{}
%\DeclareFontShape{OT1}{lcmr}{b}{it}{%
%  <6><7><8><10>gen*cmbxit%
%  <10><10.95>cmbxti10%
%  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmbxti12}{}

\DeclareFontFamily{OT1}{ltt}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{ltt}{m}{n}{%
  <6><7><8><10><12>gen*cmtt%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmtt12}{}
\DeclareFontShape{OT1}{ltt}{b}{n}{%
  <6><7><8><10><12>gen*cmttb%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmttb10}{}

\DeclareFontFamily{OT1}{sf}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{sf}{m}{n}{%
  <6><7><8><10><12>%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmsf10}{}
\DeclareFontFamily{OT1}{sc}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{sc}{m}{n}{%
  <6><7><8><10><12>%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmsc10}{}

\DeclareFontFamily{OT1}{ss}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{ss}{m}{n}{%
  <3><4><5><6>cmss6%
  <7>cmss7%
  <8>cmss8%
  <10><10.95>cmss10
  <12><14.4>cmss12%
  <17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmss12}{}
\DeclareFontShape{OT1}{ss}{it}{n}{%
  <6><7><8><10><12>gen*cmssi%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmssi12}{}
\DeclareFontShape{OT1}{ss}{m}{sl}{%
  <3><4><5><6><7><8>cmssi8%
  <9>cmssi9%
  <10><10.95>cmssi10%
  <12><14.4>cmssi12%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmssi17}{}
\DeclareFontShape{OT1}{cmss}{m}{it}{%
  <3><4><5><6><7><8>cmssi8%
  <9>cmssi9%
  <10><10.95>cmssi10%
  <12><14.4>cmssi12%
  <17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmssi17}{}
\DeclareFontShape{OT1}{cmss}{sbc}{n}{%
  <3><4><5><6><7><8><9>cmssdc10%
  <10><10.95><12><14.4><17.28>%
  <20.74><24.88><29.86><35.83><43.00><51.6>cmssdc10}{}
\DeclareFontShape{OT1}{cmss}{b}{n}{%
  <3><4><5><6><7><8><9>cmssbx10%
  <10><10.95><12><14.4><17.28>%
  <20.74><24.88><29.86><35.83><43.00><51.6>cmssbx10}{}

\DeclareFontFamily{OT1}{sx}{\hyphenchar\font45 }
\DeclareFontShape{OT1}{sx}{m}{n}{%
  <3><4><5><6><7><8><9>cmssbx10%
  <10><10.95><12><14.4><17.28>%
  <20.74><24.88><29.86><35.83><43.00><51.6>cmssbx10}{}

%-----------------------------------------------------------------------

\DeclareFontFamily{OML}{lcmm}{\skewchar\font127 }
\DeclareFontShape{OML}{lcmm}{m}{it}{%
  <6><7><8><10><12>gen*cmmi%{%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmmi12}{}
\DeclareFontShape{OML}{lcmm}{b}{it}{%
  <6><7><8><10><12>gen*cmmib%{%
  <14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmmib12}{}
\DeclareFontShape{OML}{lcmm}{b}{it}{<-> ssub * cmm/b/it}{}

%-----------------------------------------------------------------------

\DeclareFontFamily{OMS}{lcmr}{\skewchar\font'60}
\DeclareFontShape{OMS}{lcmr}{m}{n}{%
  <6><7><8><10>gen*cmsy%
  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmsy10}{}
\DeclareFontFamily{OMS}{lcmsy}{\skewchar\font'60}
\DeclareFontShape{OMS}{lcmsy}{m}{n}{%
  <6><7><8><10>gen*cmsy%
  <12><14.4><17.28><20.74><24.88><29.86><35.83><43.00><51.6>cmsy10}{}

%-----------------------------------------------------------------------

\def\rmdefault{lcmr}
\def\sfdefault{ss}
\def\sxdefault{sx}
\def\ttdefault{ltt}
\def\itdefault{it}
\def\sldefault{sl}
\def\bfdefault{b}

%-----------------------------------------------------------------------

\def\tiny{%
  \@setfontsize\tiny{10}{12\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\scriptsize{%
  \@setfontsize\scriptsize{12}{14.4\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\footnotesize{%
  \@setfontsize\footnotesize{14.4}{17.28\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\small{%
  \@setfontsize\small{17.28}{20.74\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\normalsize{%
  \@setfontsize\normalsize{20.74}{24.88\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\large{%
  \@setfontsize\large{24.88}{29.86\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\Large{%
  \@setfontsize\Large{29.86}{35.83\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\LARGE{%
  \@setfontsize\LARGE{35.83}{43\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\def\huge{%
  \@setfontsize\huge{43}{51.6\p@}%
  \baselineskip\baselinestretch\baselineskip
  \normalbaselineskip\baselineskip}

\let\Huge\huge

%-----------------------------------------------------------------------

\DeclareMathSizes{14.4}{14.4}{10}{7}
\DeclareMathSizes{17.28}{17.28}{12}{7}
\DeclareMathSizes{20.74}{20.74}{17.28}{14.4}
\DeclareMathSizes{24.88}{24.88}{20.74}{17.28}
\DeclareMathSizes{29.86}{29.86}{24.88}{20.74}
\DeclareMathSizes{35.83}{35.83}{29.86}{24.88}
\DeclareMathSizes{43.00}{43.00}{35.83}{29.86}

%-----------------------------------------------------------------------

\SetSymbolFont{operators}   {normal}{OT1}{lcmr} {m}{n}
\SetSymbolFont{letters}     {normal}{OML}{lcmm} {m}{it}
\SetSymbolFont{symbols}     {normal}{OMS}{lcmsy}{m}{n}
\SetSymbolFont{largesymbols}{normal}{OMX}{lcmex}{m}{n}

%-----------------------------------------------------------------------
\DeclareRobustCommand\sxfamily{\not@math@alphabet\sxfamily\mathsf
  \fontfamily\sxdefault\selectfont}

\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\sx}{\normalfont\sxfamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\relax}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\relax}
\DeclareRobustCommand*{\cal}{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*{\mit}{\@fontswitch{\relax}{\mathnormal}}

%-----------------------------------------------------------------------

\setlength\smallskipamount{5\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\medskipamount{10\p@ \@plus 3.5\p@ \@minus 3.5\p@}
\setlength\bigskipamount{20\p@ \@plus 7\p@ \@minus 7\p@}

%-----------------------------------------------------------------------
% List Definitions
%-----------------------------------------------------------------------

\setlength\leftmargini  {38\p@}
\setlength\leftmarginii {30\p@}
\setlength\leftmarginiii{20\p@}
\setlength\leftmarginiv {15\p@}
\setlength\leftmarginv  {15\p@}
\setlength\leftmarginvi {10\p@}

\def\@listi{\parsep .5\parskip
            \topsep \parsep
            \itemsep6mm %\itemsep\parskip
            \partopsep \z@}
\def\@listii{\leftmargin\leftmarginii
             \labelwidth\leftmarginii
             \advance\labelwidth-\labelsep
             \parsep .5\parskip
             \itemsep4mm %\itemsep\parskip
             \topsep \parsep}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep}
\def\@listiv{\leftmargin\leftmarginiv
             \labelwidth\leftmarginiv
             \advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
            \labelwidth\leftmarginv
            \advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
             \labelwidth\leftmarginvi
             \advance\labelwidth-\labelsep}
\leftmargin\leftmargini
\labelwidth\leftmargini\advance\labelwidth-\labelsep

%-----------------------------------------------------------------------

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}
\newcommand\labelenumi{\theenumi.}
\newcommand\labelenumii{(\theenumii)}
\newcommand\labelenumiii{\theenumiii.}
\newcommand\labelenumiv{\theenumiv.}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
\newcommand\labelitemi{{\normalsize $\m@th\bullet$}}
\newcommand\labelitemii{{\normalsize $\m@th\circ$}}
\newcommand\labelitemiii{{\normalsize $\m@th\ast$}}
\newcommand\labelitemiv{{\normalsize $\m@th\cdot$}}

%-----------------------------------------------------------------------
% Environments
%-----------------------------------------------------------------------
\newenvironment{quotation}{%
  \list{}{\listparindent 20\p@
  \itemindent\listparindent
  \rightmargin\leftmargin}%
  \item[]}
{\endlist}

\newenvironment{quote}{%
  \list{}{\rightmargin\leftmargin}\item[]}
{\endlist}

\newenvironment{description}{%
  \list{}{\labelwidth\z@
  \itemindent-\leftmargin
  \let\makelabel\descriptionlabel}}
{\endlist}

\newcommand*{\descriptionlabel}[1]{%
  \hspace\labelsep\normalfont\bfseries #1}

%-----------------------------------------------------------------------
% Miscellany
%-----------------------------------------------------------------------
\setlength\arraycolsep{8\p@}
\setlength\tabcolsep{10\p@}
\setlength\arrayrulewidth{.6\p@}
\setlength\doublerulesep{3\p@}
\labelsep 10pt
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{5\p@}
\setlength\fboxrule{.6\p@}

\def\theequation{\@arabic\c@equation}

\renewcommand\footnoterule{}
\def\thefootnote{\fnsymbol{footnote}}
\long\def\@makefntext#1{\noindent
  \hangindent 10\p@
  \hb@xt@10\p@{\hss\@makefnmark}#1}

\newcommand\today{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\number\day, \number\year}

%-----------------------------------------------------------------------
% Page Numbering / Labeling
%-----------------------------------------------------------------------
\def\pagenumber#1{\gdef\p@genr{#1}}
\def\title#1{\gdef\@title{#1}}
\def\author#1{\gdef\@author{#1}}

\def\@oddfoot{\raise1.6mm\hbox to\textwidth{\hss\hbox to\foot@wd{%
              \scriptsize\@author\hfil\@title\hfil\p@genr}\hss}}

%-----------------------------------------------------------------------
% Slide Definitions
%-----------------------------------------------------------------------
\def\background#1{\gdef\b@ckground{#1}}
\def\titlebackground#1{\gdef\titleb@ckground{#1}}
\def\titlecolor#1{\gdef\titlec@lor{#1}}
\def\footcolor#1{\gdef\footc@lor{#1}}
\def\rgtbox#1#2{\rule{0pt}{0pt}\phantom{#1}\hbox to0pt{\hss#2}}
\def\lftbox#1#2{\rule{0pt}{0pt}\hbox to0pt{#2\hss}\phantom{#1}}

%-----------------------------------------------------------------------
\newdimen\tmpx
\newdimen\tmpy

\def\putb@ckground{\noindent\if\b@ckground\empty\hbox{}\else
  \tmpx\paperwidth \advance\tmpx-\textwidth \divide\tmpx2
  \tmpy\paperheight\advance\tmpy-\textheight\divide\tmpy2
  \advance\tmpy-3mm
  \vbox to0pt{\vskip-\tmpy\hbox to0pt{\hskip-\tmpx
    \vbox to\paperheight{\vss
    \hbox to\paperwidth{\hss\b@ckground\hss}}\hss}\vss}\fi}

%-----------------------------------------------------------------------

\def\titleslide{%
\ifx\pdfoutput\undefined\special{landscape}\fi
\putb@ckground{\unitlength1mm
\hbox to0pt{\hskip-1in\hskip-\oddsidemargin
\begin{picture}(0,0)\thicklines
\if\titlec@lor\empty\else
  \put(0, -12){\fboxsep0mm\colorbox{\titlec@lor}{%
    \makebox(\slide@wd,12){}}}\fi
\if\footc@lor\empty\else
  \put(0,-210){\fboxsep0mm\colorbox{\footc@lor}{%
    \makebox(\slide@wd,6){}}}\fi
% 0.0879mm ~= 0.25pt
% 0.1757mm ~= 0.50pt
\put( 0.0000,  -0.1757){\line(1,0){\slide@wd}}
\put( 0.0000,-209.8243){\line(1,0){\slide@wd}}
\put( 0.0000, -12.0000){\line(1,0){\slide@wd}}
\put( 0.0000,-204.0000){\line(1,0){\slide@wd}}
\put( 0.0879,-210.0000){\line(0,1){\slide@wd}}
\put(-0.0879,-210.0000){\put(\slide@wd,0){\line(0,1){\slide@wd}}}
\end{picture}\hss}\par}\center\vfill}
\def\endtitleslide{\vfill\endcenter\newpage}

%-----------------------------------------------------------------------
\@namedef{slide*}{\slide}
\@namedef{endslide*}{\endslide\global\advance\c@page-1}

\def\slide#1{%
\ifx\pdfoutput\undefined\special{landscape}\fi
\putb@ckground{\unitlength1mm
\hbox to0pt{\hskip-1in\hskip-\oddsidemargin
\begin{picture}(0,0)\thicklines
\if\titleb@ckground\empty\else
  \put(0, -24){\makebox(\slide@wd,24){\titleb@ckground}}\fi
\if\titlec@lor\empty\else
  \put(0, -24){\fboxsep0mm\colorbox{\titlec@lor}{%
    \makebox(\slide@wd,24){}}}\fi
\if\footc@lor\empty\else
  \put(0,-210){\fboxsep0mm\colorbox{\footc@lor}{%
    \makebox(\slide@wd,6){}}}\fi
\put( 0.0000,  -0.0879){\line(1,0){\slide@wd}}
\put( 0.0000,-209.9121){\line(1,0){\slide@wd}}
\put( 0.0000, -24.0000){\line(1,0){\slide@wd}}
\put( 0.0000,-204.0000){\line(1,0){\slide@wd}}
\put( 0.0879,-210.0000){\line(0,1){\slide@wd}}
\put(-0.0879,-210.0000){\put(\slide@wd,0){\line(0,1){\slide@wd}}}
\put( 0.0000, -24.0000){\makebox(\slide@wd,24){\large\bf#1%
                                 \hbox to0pt{\phantom{Hgp\"U}\hss}}}
\end{picture}\hss}}\par\hrule\@height\z@\vskip36mm}
\def\endslide{\par\newpage}

%-----------------------------------------------------------------------

\def\emptyslide{\newpage
\ifx\pdfoutput\undefined\special{landscape}\fi
\putb@ckground\center\vfill}
\def\endemptyslide{\vfill\endcenter}

%-----------------------------------------------------------------------
% Initial Settings
%-----------------------------------------------------------------------
\abovedisplayskip      0\p@
\belowdisplayskip      \abovedisplayskip
\abovedisplayshortskip 0\p@
\belowdisplayshortskip \abovedisplayshortskip

\def\p@genr{\thepage}
\let\@title\empty
\let\@author\empty
\let\b@ckground\empty
\let\titleb@ckground\empty
\let\titlec@lor\empty
\pagenumbering{arabic}
\renewcommand\baselinestretch{}
\normalsize

%-----------------------------------------------------------------------

\endinput
